@@ -6,6 +6,8 @@ from .context import connected
 from .context import handle_exit
 from .core import *
 from .helpers import dictify
+from .helpers import LogJson
+from .log import get_logger
 from .oem import *
 
 as_dict_all = dictify  # alias
